@@ -2,13 +2,19 @@
 """
 Tests plot.
 """
+import datetime
 import os
 
 import numpy as np
+import pandas as pd
+import xarray as xr
+
 import pytest
 
 from .. import Figure
 from ..exceptions import GMTInvalidInput
+from ..helpers import GMTTempFile
+from ..helpers.testing import check_figures_equal
 
 
 TEST_DATA_DIR = os.path.join(os.path.dirname(__file__), "data")
@@ -122,11 +128,21 @@ def test_plot_projection(data):
     return fig
 
 
-@pytest.mark.mpl_image_compare
+@check_figures_equal()
 def test_plot_colors(data, region):
-    "Plot the data using z as sizes"
-    fig = Figure()
-    fig.plot(
+    "Plot the data using z as colors"
+    fig_ref, fig_test = Figure(), Figure()
+    # Use single-character arguments for the reference image
+    fig_ref.plot(
+        data=POINTS_DATA,
+        R="/".join(map(str, region)),
+        J="X3i",
+        S="c0.5c",
+        C="cubhelix",
+        B="af",
+    )
+
+    fig_test.plot(
         x=data[:, 0],
         y=data[:, 1],
         color=data[:, 2],
@@ -136,7 +152,7 @@ def test_plot_colors(data, region):
         cmap="cubhelix",
         frame="af",
     )
-    return fig
+    return fig_ref, fig_test
 
 
 @pytest.mark.mpl_image_compare
@@ -190,6 +206,104 @@ def test_plot_colors_sizes_proj(data, region):
     return fig
 
 
+@check_figures_equal()
+def test_plot_transparency():
+    "Plot the data with a constant transparency"
+    x = np.arange(1, 10)
+    y = np.arange(1, 10)
+
+    fig_ref, fig_test = Figure(), Figure()
+    # Use single-character arguments for the reference image
+    with GMTTempFile() as tmpfile:
+        np.savetxt(tmpfile.name, np.c_[x, y], fmt="%d")
+        fig_ref.plot(
+            data=tmpfile.name, S="c0.2c", G="blue", t=80.0, R="0/10/0/10", J="X4i", B=""
+        )
+
+    fig_test.plot(
+        x=x,
+        y=y,
+        region=[0, 10, 0, 10],
+        projection="X4i",
+        frame=True,
+        style="c0.2c",
+        color="blue",
+        transparency=80.0,
+    )
+    return fig_ref, fig_test
+
+
+@check_figures_equal()
+def test_plot_varying_transparency():
+    "Plot the data using z as transparency"
+    x = np.arange(1, 10)
+    y = np.arange(1, 10)
+    z = np.arange(1, 10) * 10
+
+    fig_ref, fig_test = Figure(), Figure()
+    # Use single-character arguments for the reference image
+    with GMTTempFile() as tmpfile:
+        np.savetxt(tmpfile.name, np.c_[x, y, z], fmt="%d")
+        fig_ref.plot(
+            data=tmpfile.name,
+            R="0/10/0/10",
+            J="X4i",
+            B="",
+            S="c0.2c",
+            G="blue",
+            t="",
+        )
+
+    fig_test.plot(
+        x=x,
+        y=y,
+        region=[0, 10, 0, 10],
+        projection="X4i",
+        frame=True,
+        style="c0.2c",
+        color="blue",
+        transparency=z,
+    )
+    return fig_ref, fig_test
+
+
+@check_figures_equal()
+def test_plot_sizes_colors_transparencies():
+    "Plot the data with varying sizes and colors using z as transparency"
+    x = np.arange(1.0, 10.0)
+    y = np.arange(1.0, 10.0)
+    color = np.arange(1, 10) * 0.15
+    size = np.arange(1, 10) * 0.2
+    transparency = np.arange(1, 10) * 10
+
+    fig_ref, fig_test = Figure(), Figure()
+    # Use single-character arguments for the reference image
+    with GMTTempFile() as tmpfile:
+        np.savetxt(tmpfile.name, np.c_[x, y, color, size, transparency])
+        fig_ref.plot(
+            data=tmpfile.name,
+            R="0/10/0/10",
+            J="X4i",
+            B="",
+            S="cc",
+            C="gray",
+            t="",
+        )
+    fig_test.plot(
+        x=x,
+        y=y,
+        region=[0, 10, 0, 10],
+        projection="X4i",
+        frame=True,
+        style="cc",
+        color=color,
+        sizes=size,
+        cmap="gray",
+        transparency=transparency,
+    )
+    return fig_ref, fig_test
+
+
 @pytest.mark.mpl_image_compare
 def test_plot_matrix(data):
     "Plot the data passing in a matrix and specifying columns"
@@ -284,3 +398,47 @@ def test_plot_scalar_xy():
     fig.plot(x=0, y=0, style="t1c")
     fig.plot(x=1.5, y=-1.5, style="s1c")
     return fig
+
+
+@pytest.mark.mpl_image_compare
+def test_plot_datetime():
+    """Test various datetime input data"""
+    fig = Figure()
+    fig.basemap(
+        projection="X15c/5c",
+        region=[
+            np.array("2010-01-01T00:00:00", dtype=np.datetime64),
+            pd.Timestamp("2020-01-01"),
+            0,
+            10,
+        ],
+        frame=True,
+    )
+
+    # numpy.datetime64 types
+    x = np.array(
+        ["2010-06-01", "2011-06-01T12", "2012-01-01T12:34:56"], dtype="datetime64"
+    )
+    y = [1.0, 2.0, 3.0]
+    fig.plot(x, y, style="c0.2c", pen="1p")
+
+    # pandas.DatetimeIndex
+    x = pd.date_range("2013", freq="YS", periods=3)
+    y = [4, 5, 6]
+    fig.plot(x, y, style="t0.2c", pen="1p")
+
+    # xarray.DataArray
+    x = xr.DataArray(data=pd.date_range(start="2015-03", freq="QS", periods=3))
+    y = [7.5, 6, 4.5]
+    fig.plot(x, y, style="s0.2c", pen="1p")
+
+    # raw datetime strings
+    x = ["2016-02-01", "2017-03-04T00:00"]
+    y = [7, 8]
+    fig.plot(x, y, style="a0.2c", pen="1p")
+
+    # the Python built-in datetime and date
+    x = [datetime.date(2018, 1, 1), datetime.datetime(2019, 1, 1)]
+    y = [8.5, 9.5]
+    fig.plot(x, y, style="i0.2c", pen="1p")
+    return fig
